@@ -1,7 +1,4 @@
-use crate::{
-    cargo::CargoRanges,
-    sonar::{Issue, IssueType, Issues, Location, Severity, TextRange},
-};
+use crate::{cargo::CargoRanges, sonar};
 use eyre::{Context, Result};
 use rustsec::{Report, Vulnerability};
 use std::{fs::File, path::PathBuf};
@@ -27,7 +24,7 @@ impl<'ranges> Audit<'ranges> {
 
     // FIXME: reporting on 'Cargo.toml' is a bad idea because the vulnerability might exist on a nested dependency
     // it might be possible to use 'Cargo.lock' instead (or use 'cargo-deny' to obtain a graph of dependency and find the root dependency)
-    fn to_issue(&self, vulnerability: &Vulnerability) -> Issue {
+    fn to_issue(&self, vulnerability: &Vulnerability) -> sonar::Issue {
         let advisory = &vulnerability.advisory;
         let rule_id = Some(advisory.id.to_string());
         let message = format!(
@@ -46,32 +43,32 @@ impl<'ranges> Audit<'ranges> {
                     .get(advisory.package.as_str())
                     .map(|ranges| &ranges.0)
             })
-            .map(|range| TextRange::clone(range))
+            .map(|range| sonar::TextRange::clone(range))
             .unwrap_or_else(|| {
                 error!("failed to find a corresponding text range for this vulnerability. This is probably a bug in `cargo-sonar`, if you can please report an issue, we'd be happy to try and fix it.");
-                TextRange {
+                sonar::TextRange {
                     start_line: 1,
                     end_line: 1,
                     start_column: 0,
                     end_column: 1,
                 }
             });
-        let primary_location = Location {
+        let primary_location = sonar::Location {
             message,
             file_path,
             text_range,
         };
         let secondary_locations = Vec::new();
-        Issue {
+        sonar::Issue {
             engine_id: AUDIT_ENGINE.to_string(),
             rule_id,
-            severity: Severity::Major,
-            r#type: IssueType::Vulnerability,
+            severity: sonar::Severity::Major,
+            r#type: sonar::IssueType::Vulnerability,
             primary_location,
             secondary_locations,
         }
     }
-    pub fn to_issues(&self, report: Report) -> Issues {
+    pub fn to_issues(&self, report: Report) -> sonar::Report {
         report
             .vulnerabilities
             .list
@@ -81,10 +78,10 @@ impl<'ranges> Audit<'ranges> {
     }
 }
 
-impl std::convert::TryInto<Issues> for Audit<'_> {
+impl std::convert::TryInto<sonar::Report> for Audit<'_> {
     type Error = eyre::Error;
 
-    fn try_into(self) -> Result<Issues> {
+    fn try_into(self) -> Result<sonar::Report> {
         let file = File::open(&self.json)?;
         let report = serde_json::from_reader::<_, Report>(file)
             .context("failed to be parsed as a 'rustsec::report::Report'")?;
@@ -93,9 +90,3 @@ impl std::convert::TryInto<Issues> for Audit<'_> {
         Ok(issues)
     }
 }
-
-impl From<Report> for Issues {
-    fn from(_: Report) -> Self {
-        Self::default()
-    }
-}
