@@ -1,4 +1,4 @@
-use crate::sonar::{Issue, IssueType, Issues, Location, Severity, TextRange};
+use crate::sonar;
 use cargo_metadata::{
     diagnostic::{DiagnosticLevel, DiagnosticSpan},
     Message,
@@ -26,21 +26,21 @@ pub enum Error {
     InvalidMessage(&'static str),
 }
 
-impl From<&DiagnosticLevel> for Severity {
+impl From<&DiagnosticLevel> for sonar::Severity {
     fn from(level: &DiagnosticLevel) -> Self {
         use DiagnosticLevel::*;
         match level {
-            Ice => Severity::Blocker,
-            Error => Severity::Critical,
-            Warning => Severity::Major,
-            FailureNote => Severity::Minor,
-            Note | Help => Severity::Info,
-            _ => Severity::Info,
+            Ice => sonar::Severity::Blocker,
+            Error => sonar::Severity::Critical,
+            Warning => sonar::Severity::Major,
+            FailureNote => sonar::Severity::Minor,
+            Note | Help => sonar::Severity::Info,
+            _ => sonar::Severity::Info,
         }
     }
 }
 
-impl From<&DiagnosticSpan> for TextRange {
+impl From<&DiagnosticSpan> for sonar::TextRange {
     fn from(span: &DiagnosticSpan) -> Self {
         Self {
             start_line: span.line_start,
@@ -53,7 +53,7 @@ impl From<&DiagnosticSpan> for TextRange {
     }
 }
 
-impl TryFrom<Message> for Issue {
+impl TryFrom<Message> for sonar::Issue {
     type Error = Error;
     fn try_from(message: Message) -> Result<Self, Self::Error> {
         use Message::*;
@@ -63,23 +63,23 @@ impl TryFrom<Message> for Issue {
                 .code
                 .as_ref()
                 .map(|diagnostic_code| diagnostic_code.code.clone());
-            let severity = Severity::from(&message.message.level);
-            let r#type = IssueType::CodeSmell;
+            let severity = sonar::Severity::from(&message.message.level);
+            let r#type = sonar::IssueType::CodeSmell;
             let (primary_location, secondary_locations) = match message.message.spans.len() {
                 0 => return Err(Error::NoSpan),
                 n => {
                     let span = &message.message.spans[0];
-                    let primary_location = Location {
+                    let primary_location = sonar::Location {
                         message: message.message.message.clone(),
                         file_path: span.file_name.clone(),
-                        text_range: TextRange::from(span),
+                        text_range: sonar::TextRange::from(span),
                     };
                     let secondary_locations = (1..n)
                         .flat_map(|idx| message.message.spans.get(idx))
-                        .map(|span| Location {
+                        .map(|span| sonar::Location {
                             message: message.message.message.clone(),
                             file_path: span.file_name.clone(),
-                            text_range: TextRange::from(span),
+                            text_range: sonar::TextRange::from(span),
                         })
                         .collect();
                     (primary_location, secondary_locations)
@@ -119,17 +119,17 @@ impl Clippy {
     }
 }
 
-impl std::convert::TryInto<Issues> for Clippy {
+impl std::convert::TryInto<sonar::Report> for Clippy {
     type Error = eyre::Error;
 
-    fn try_into(self) -> Result<Issues, Self::Error> {
+    fn try_into(self) -> Result<sonar::Report, Self::Error> {
         let file = File::open(&self.json)?;
         let reader = BufReader::new(file);
-        let issues: Issues = reader
+        let issues: sonar::Report = reader
             .lines()
             .flatten()
             .flat_map(|line| serde_json::from_str::<cargo_metadata::Message>(&line))
-            .map(Issue::try_from)
+            .map(sonar::Issue::try_from)
             .skip_error_and_debug()
             .collect();
         info!("{} sonar issues created", issues.len());
