@@ -1,9 +1,15 @@
+#![doc = include_str!("../README.md")]
+
+#[cfg(feature = "audit")]
 mod audit;
+#[cfg(feature = "audit")]
 mod cargo;
+mod cli;
+#[cfg(feature = "clippy")]
 mod clippy;
 mod sonar;
-use crate::{audit::Audit, cargo::CargoRanges, clippy::Clippy, sonar::Issues};
 
+use clap::Parser;
 use eyre::{Context as _, Result};
 use tracing::{info, Level};
 use tracing_subscriber::{prelude::*, EnvFilter};
@@ -30,20 +36,33 @@ fn init_tracer() {
 fn main() -> Result<()> {
     init_tracer();
     color_eyre::install()?;
-    let cargo_ranges =
-        CargoRanges::try_from(std::env::current_dir()?.join("Cargo.toml").as_path())?;
-    let clippy_issues: Issues = Clippy::new("clippy.json").try_into()?;
-    let audit_issues: Issues = Audit::new("audit.json", &cargo_ranges).try_into()?;
-
-    let mut issues = clippy_issues;
-    issues.extend(audit_issues);
+    let options = cli::Command::parse();
 
+    #[cfg(feature = "audit")]
+    let cargo_ranges = {
+        let cargo_toml = std::env::current_dir()?.join("Cargo.toml");
+        cargo::CargoRanges::try_from(cargo_toml.as_path())?
+    };
+    let mut sonar_report = sonar::Report::default();
+    #[cfg(feature = "audit")]
+    if options.audit {
+        use crate::audit::Audit;
+        let audit_report: sonar::Report =
+            Audit::new(options.audit_path, &cargo_ranges).try_into()?;
+        sonar_report.extend(audit_report);
+    }
+    #[cfg(feature = "clippy")]
+    if options.clippy {
+        use crate::clippy::Clippy;
+        let clippy_report: sonar::Report = Clippy::new(options.clippy_path).try_into()?;
+        sonar_report.extend(clippy_report);
+    }
     let file = std::fs::File::create("sonar.json").context("failed to create 'sonar.json' file")?;
-    info!("{} sonar issues created", issues.len());
+    info!("{} sonar issues created", sonar_report.len());
     #[cfg(not(debug_assertions))]
     let writer = serde_json::to_writer;
     #[cfg(debug_assertions)]
     let writer = serde_json::to_writer_pretty;
-    writer(file, &issues).context("failed to write sonar issues to 'sonar.json' file")?;
+    writer(file, &sonar_report).context("failed to write sonar issues to 'sonar.json' file")?;
     Ok(())
 }
